"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var core_1 = require("@angular/core");
var ng2_file_upload_1 = require("ng2-file-upload");
var _ = require("lodash");
var FileUploadComponent = (function () {
    function FileUploadComponent() {
        this.fileAcceptType = {
            '.jpg': 'image/jpeg',
            '.jpeg': 'image/jpeg',
            '.gif': 'image/gif',
            '.csv': 'text/csv',
            '.doc': 'application/msword',
            '.png': 'image/png',
            '.ppt': 'application/vnd.ms-powerpoint',
            '.wps': 'application/vnd.ms-works',
            '.xls': 'application/vnd.ms-excel',
            '.xml': 'text/xml,application/xml',
            '.zip': 'application/zip',
            '.xlsx': 'application/vnd.openxmlformats-officedocument.spreadsheetml.sheet',
            '.xltx': 'application/vnd.openxmlformats-officedocument.spreadsheetml.template',
            '.pptx': 'application/vnd.openxmlformats-officedocument.presentationml.presentation',
            '.docx': 'application/vnd.openxmlformats-officedocument.wordprocessingml.document',
        };
        this.fileChangeEvent = new core_1.EventEmitter();
        this.success = new core_1.EventEmitter();
        this.error = new core_1.EventEmitter();
    }
    Object.defineProperty(FileUploadComponent.prototype, "acceptType", {
        get: function () {
            return this._acceptType;
        },
        set: function (v) {
            var temp = [];
            this.acceptTypeArr = v || null;
            if (v && v.length > 0) {
                for (var i = 0; i < v.length; i++) {
                    if (this.fileAcceptType[v[i]] !== undefined) {
                        temp.push(this.fileAcceptType[v[i]]);
                    }
                }
            }
            if (temp.length > 0) {
                this._acceptType = temp.join(',');
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(FileUploadComponent.prototype, "options", {
        get: function () {
            return this._options;
        },
        set: function (v) {
            this._options = v;
            this.uploader = new ng2_file_upload_1.FileUploader(this._options);
            this.uploader.onSuccessItem = this.successItem.bind(this);
            this.uploader.onErrorItem = this.errorItem.bind(this);
        },
        enumerable: true,
        configurable: true
    });
    FileUploadComponent.prototype.ngOnInit = function () {
    };
    FileUploadComponent.prototype.selectedFileOnChanged = function (event) {
        if (!event.target.value) {
            return;
        }
        var fileItem = event.target.files[0];
        this.checkFileItem(fileItem);
        this.fileChangeEvent.emit(event);
    };
    FileUploadComponent.prototype.checkFileItem = function (fileItem) {
        if (!fileItem) {
            return;
        }
        var fileSize = fileItem.size;
        if (this.fileMaxSize && fileSize > this.fileMaxSize) {
            this.error.emit('overSize');
            this.clearFileItem();
        }
        else {
            if (fileItem.name.lastIndexOf('.') === -1) {
                this.error.emit('errorType');
                this.clearFileItem();
            }
            else {
                var fileSuffix_1 = fileItem.name.slice(fileItem.name.lastIndexOf('.'));
                if (this.acceptTypeArr && this.acceptTypeArr.length > 0) {
                    var index = _.findIndex(this.acceptTypeArr, function (o) {
                        return o == fileSuffix_1;
                    });
                    if (index === -1) {
                        this.error.emit('errorType');
                        this.clearFileItem();
                    }
                }
            }
        }
    };
    FileUploadComponent.prototype.clearFileItem = function () {
        this.uploader.clearQueue();
        this.fileUploadInput.nativeElement.value = '';
    };
    FileUploadComponent.prototype.successItem = function (event, res) {
        this.success.emit({
            fileitem: event,
            response: res
        });
    };
    FileUploadComponent.prototype.errorItem = function (event, res) {
        this.error.emit(res);
    };
    FileUploadComponent.decorators = [
        { type: core_1.Component, args: [{
                    selector: 'dc-file-upload',
                    template: "\n    <input #fileUploadInput type=\"file\" ng2FileSelect [uploader]=\"uploader\" [accept]=\"acceptType || ''\"\n           (change)=\"selectedFileOnChanged($event)\"/>\n  ",
                    styles: [
                        "\n    "
                    ]
                },] },
    ];
    /** @nocollapse */
    FileUploadComponent.ctorParameters = function () { return []; };
    FileUploadComponent.propDecorators = {
        "fileMaxSize": [{ type: core_1.Input },],
        "acceptType": [{ type: core_1.Input },],
        "fileChangeEvent": [{ type: core_1.Output },],
        "success": [{ type: core_1.Output },],
        "error": [{ type: core_1.Output },],
        "options": [{ type: core_1.Input },],
        "fileUploadInput": [{ type: core_1.ViewChild, args: ['fileUploadInput',] },],
    };
    return FileUploadComponent;
}());
exports.FileUploadComponent = FileUploadComponent;
//# sourceMappingURL=file.upload.component.js.map